
From: Arjan van de Ven <arjanv@redhat.com>

Right now the kernel detects the sysadmin trying to set the iocharset of
vfat to UTF8 and prevents this with an error.  While I can see that this is
not recommended, enforcing this is policy that probably doesn't belong in
the kernel.  The patch below makes this situation a warning and a
recommendation instead of a strong blockage.

https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=126641

is an example of a sysadmin disliking this policy enforcement.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/fat/inode.c |    5 ++---
 1 files changed, 2 insertions(+), 3 deletions(-)

diff -puN fs/fat/inode.c~allow-root-to-choose-vfat-policy-to-utf8 fs/fat/inode.c
--- 25/fs/fat/inode.c~allow-root-to-choose-vfat-policy-to-utf8	Thu Jun 24 15:37:46 2004
+++ 25-akpm/fs/fat/inode.c	Thu Jun 24 15:37:46 2004
@@ -499,9 +499,8 @@ static int parse_options(char *options, 
 	}
 	/* UTF8 doesn't provide FAT semantics */
 	if (!strcmp(opts->iocharset, "utf8")) {
-		printk(KERN_ERR "FAT: utf8 is not a valid IO charset"
-		       " for FAT filesystems\n");
-		return -EINVAL;
+		printk(KERN_ERR "FAT: utf8 is not a recommended IO charset"
+		       " for FAT filesystems, filesystem will be case sensitive!\n");
 	}
 
 	if (opts->unicode_xlate)
_
